// Copyright (c) 2006 David Drysdale.  See license.txt for license info
import java.awt.*;

class DisplayThread extends Thread {
  private Canvas canvas;
  private boolean done;
  public String data;
  
  public DisplayThread(LetterCanvas c) {
    canvas = c;
    done = false;
    data = "";
  }
  public synchronized void run() {
    Dimension d = canvas.getSize();
    Graphics g = canvas.getGraphics();
    Font font = new Font("Helvetica", Font.BOLD, 150);
    g.setFont(font);
    FontMetrics fm = g.getFontMetrics(font);
    int x;
    int y = ((d.height - fm.getMaxAscent()) / 2) + fm.getAscent();
    while (!done) {
      // Pick a letter at random
      int i = (int)'A' + (int)Math.floor(Math.random() * 26);
      char c[] = {(char)i};

      // Decide if it is black or white
      boolean white = (Math.random() > 0.95);
      Color color = (white? Color.white : Color.black);

      // Display
      x = (d.width - fm.charsWidth(c,0,1)) / 2;
      g.setColor(color);
      g.drawChars(c,0,1,x,y);
      synchronized (data) {
        if ((!white) && (c[0] != 'X')) {
          data = data + Character.toLowerCase(c[0]);
        } else {
          data = data + c[0];
        }
      }

      // Wait 100 ms
      try {
        Thread.sleep(100);
      } catch (InterruptedException e) {}
      // Clear
      canvas.paint(canvas.getGraphics());
    }
  }
  public void mark() {
    synchronized (data) {
      if (data.length() != 0) {
        data = data + '*';
      }
    }
  }
  public void term() {
    done = true;
  }
}